@@ -6,7 +6,7 @@ import torch
 from torch.utils.data import Dataset, DataLoader
 
 from tf_bind_transformer.data import FactorProteinDataset, ContextDataset, cast_list, filter_df_by_tfactor_fastas
-from tf_bind_transformer.data import pl_isin, pl_notin, fetch_experiments_index, parse_exp_target_cell, read_bed, cycle
+from tf_bind_transformer.data import pl_isin, pl_notin, fetch_experiments_index, parse_exp_target_cell, read_bed, cycle, filter_by_col_isin
 from tf_bind_transformer.data import CHR_IDS, CHR_NAMES, get_chr_names
 from enformer_pytorch import FastaInterval
 
@@ -60,6 +60,7 @@ class BigWigDataset(Dataset):
         include_biotypes_metadata_columns = [],
         biotypes_metadata_delimiter = ' | ',
         only_ref = ['mm10', 'hg38'],
+        factor_species_priority = ['human', 'mouse'],
         downsample_factor = 128,
         target_length = 896,
         bigwig_reduction_type = 'sum',
@@ -80,7 +81,7 @@ class BigWigDataset(Dataset):
         annot_df = annot_df.filter(pl_isin('column_2', only_ref))
 
         # :TODO find out why this step is taking forever
-        annot_df = annot_df.filter(pl_isin('column_1', bw_experiments))
+        annot_df = filter_by_col_isin(annot_df, 'column_1', bw_experiments)
 
         if df_frac < 1:
             annot_df = annot_df.sample(frac = df_frac)
@@ -99,7 +100,7 @@ class BigWigDataset(Dataset):
             col_name, col_val = filter_sequences_by
             loci = loci.filter(pl.col(col_name) == col_val)
 
-        self.factor_ds = FactorProteinDataset(factor_fasta_folder)
+        self.factor_ds = FactorProteinDataset(factor_fasta_folder, species_priority = factor_species_priority)
 
         annot_df = chip_atlas_add_experiment_target_cell(annot_df)
         annot_df = filter_df_by_tfactor_fastas(annot_df, factor_fasta_folder)
