@@ -78,6 +78,7 @@ class BigWigTrainer(nn.Module):
             bigwig_reduction_type = bigwig_reduction_type,
             filter_sequences_by = ('column_4', 'train'),
             only_ref = ['hg38'],
+            factor_species_priority = ['human', 'mouse', 'unknown']
         )
 
         self.valid_human_ds = BigWigDataset(
@@ -96,7 +97,8 @@ class BigWigTrainer(nn.Module):
             rc_aug = rc_aug,
             bigwig_reduction_type = bigwig_reduction_type,
             filter_sequences_by = ('column_4', 'valid'),
-            only_ref = ['hg38']
+            only_ref = ['hg38'],
+            factor_species_priority = ['human', 'mouse', 'unknown']
         )
 
         self.mouse_ds = BigWigDataset(
@@ -115,7 +117,8 @@ class BigWigTrainer(nn.Module):
             rc_aug = rc_aug,
             bigwig_reduction_type = bigwig_reduction_type,
             filter_sequences_by = ('column_4', 'train'),
-            only_ref = ['mm10']
+            only_ref = ['mm10'],
+            factor_species_priority = ['mouse', 'human', 'unknown']
         )
 
         self.valid_mouse_ds = BigWigDataset(
@@ -134,7 +137,8 @@ class BigWigTrainer(nn.Module):
             rc_aug = rc_aug,
             bigwig_reduction_type = bigwig_reduction_type,
             filter_sequences_by = ('column_4', 'valid'),
-            only_ref = ['mm10']
+            only_ref = ['mm10'],
+            factor_species_priority = ['mouse', 'human', 'unknown']
         )
 
         len_train_human = len(self.human_ds)
@@ -153,11 +157,13 @@ class BigWigTrainer(nn.Module):
 
         assert self.has_human or self.has_mouse, 'must have training samples for either human or mouse'
 
-        self.train_human_dl = get_bigwig_dataloader(self.human_ds, cycle_iter = True, shuffle = shuffle, batch_size = batch_size)
-        self.train_mouse_dl = get_bigwig_dataloader(self.mouse_ds, cycle_iter = True, shuffle = shuffle, batch_size = batch_size)
+        if self.has_human:
+            self.train_human_dl = get_bigwig_dataloader(self.human_ds, cycle_iter = True, shuffle = shuffle, batch_size = batch_size)
+            self.valid_human_dl = get_bigwig_dataloader(self.valid_human_ds, cycle_iter = True, shuffle = shuffle, batch_size = batch_size)
 
-        self.valid_human_dl = get_bigwig_dataloader(self.valid_human_ds, cycle_iter = True, shuffle = shuffle, batch_size = batch_size)
-        self.valid_mouse_dl = get_bigwig_dataloader(self.valid_mouse_ds, cycle_iter = True, shuffle = shuffle, batch_size = batch_size)
+        if self.has_mouse:
+            self.train_mouse_dl = get_bigwig_dataloader(self.mouse_ds, cycle_iter = True, shuffle = shuffle, batch_size = batch_size)
+            self.valid_mouse_dl = get_bigwig_dataloader(self.valid_mouse_ds, cycle_iter = True, shuffle = shuffle, batch_size = batch_size)
 
         self.optim = get_optimizer(model.parameters(), lr = lr, wd = wd)
 
